import { TwitterShareButton, FacebookShareButton, TelegramShareButton, LinkedinShareButton } from 'react-share';
import React, { ComponentPropsWithoutRef, FC } from 'react';
import { cva } from 'class-variance-authority';
import { Icon } from '../../molecules/Icon';
import { cssMerge } from '../../utils/cssMerge';
import { useCopyToClipboard } from '../../utils/hooks/useCopyToClipboard';

interface SocialShareButtonProps extends ComponentPropsWithoutRef<'div'> {
  url: string;
  title?: string;
  color?: 'purple';
}

const button = cva(['tw-cursor-pointer'], {
  variants: {
    color: {
      purple: ['tw-text-purple-500', 'hover:tw-text-common-white'],
    },
  },
  defaultVariants: {
    color: 'purple',
  },
});

export const SocialShareButtons: FC<SocialShareButtonProps> = ({ url, title, className, color, ...props }) => {
  const { copy } = useCopyToClipboard();

  return (
    <div className={cssMerge('tw-flex', 'tw-gap-6', className)} {...props}>
      <TwitterShareButton url={url} title={title}>
        <Icon id="twitter-share" className={button({ color })} />
      </TwitterShareButton>
      <FacebookShareButton url={url}>
        <Icon id="facebook-share" className={button({ color })} />
      </FacebookShareButton>
      <LinkedinShareButton url={url} title={title}>
        <Icon id="linkedin-share" className={button({ color })} />
      </LinkedinShareButton>
      <TelegramShareButton url={url} title={title}>
        <Icon id="telegram-share" className={button({ color })} />
      </TelegramShareButton>
      {/* TODO: Add Tooltip notification on copy after tooltip development  */}
      <Icon id="link" onClick={() => copy(url)} className={button({ color })} role="button" aria-label="Copy URL" />
    </div>
  );
};
